package TwilightMinds.Log;

/**
 * An EntryType object records a type of LogEntry that has an identifying 
 * name and is written to a specific Log.
 * <br><br>
 * Author: Reason <br>
 * Last Modified: 11/23/00
 * <br><br>
 * ------------------------------------------------
 * <br><br>                           
 * Copyright (C) 2000 Twilight Minds. All rights reserved.
 * <br><br>
 * This Java package is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * <br><br>
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * <br><br>
 * You should have received a copy of the GNU Lesser General Public 
 * License along with this package; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
 * MA 02111-1307 USA
 * <br><br>
 * Alternatively, a copy can be obtained from the Twilight Minds web
 * site: <a href="http://www.twilightminds.com/GNU-LGPL.html">
 * http://www.twilightminds.com/GNU-LGPL.html</a>
 * <br><br>
 * Twilight Minds Design Group
 * <a href="http://www.twilightminds.com/">http://www.twilightminds.com/</a>
 * 
 */
public class EntryType
{
	private String name;
	private Log log;
	private boolean islogging;

	/**
	 * The standard constructor for the EventType class. This EventType will
	 * be logged by default.
	 */
	public EntryType(String inputname, Log inputlog)
	{
		name = inputname;
		log = inputlog;
		islogging = true;
	}
	
	/**
	 * This constructor allows the islogging variable to be specified, determining
	 * whether or not LogEntries of this EventType will be logged.
	 */
	public EntryType(String inputname, Log inputlog, boolean inputislogging)
	{
		name = inputname;
		log = inputlog;
		islogging = inputislogging;
	}
	
	/**
	 * Return the identifying name of this EntryType object.
	 */
	public String getName()
	{
		return name;	
	}
	
	/**
	 * Return the identifying name of the Log that entries of this
	 * type are sent to.
	 */
	public String getLogName()
	{
		return log.getLogName();
	}	
	
	/**
	 * Return the Log object that entries of this type are sent to.
	 */
	public Log getLog()
	{
		return log;
	}
	
	/**
	 * Set the Log object that entries of this type are sent to.
	 */
	public void setLog(Log inputlog)
	{
		log = inputlog;
	}
	
	/**
	 * LogEntries of this EntryType will now be logged.
	 */
	public void startLogging()
	{
		islogging = true;	
	}
	
	/**
	 * LogEntries of this EntryType will now not be logged.
	 */
	public void stopLogging()
	{
		islogging = false;	
	}
	
	/**
	 * Return the logging status of all LogEntries of this EventType.
	 * False indicates that they will not be logged.
	 */
	public boolean isLogging()
	{
		return islogging;	
	}
	
}
