package TwilightMinds.Log;

import java.util.*;

/**
 * An object of the LogEntry class holds the information needed for a 
 * single entry into a Log.
 * <br><br>
 * Author: Reason <br>
 * Last Modified: 12/06/00
 * <br><br>
 * ------------------------------------------------
 * <br><br>                           
 * Copyright (C) 2000 Twilight Minds. All rights reserved.
 * <br><br>
 * This Java package is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * <br><br>
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * <br><br>
 * You should have received a copy of the GNU Lesser General Public 
 * License along with this package; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
 * MA 02111-1307 USA
 * <br><br>
 * Alternatively, a copy can be obtained from the Twilight Minds web
 * site: <a href="http://www.twilightminds.com/GNU-LGPL.html">
 * http://www.twilightminds.com/GNU-LGPL.html</a>
 * <br><br>
 * Twilight Minds Design Group
 * <a href="http://www.twilightminds.com/">http://www.twilightminds.com/</a>
 * 
 */
public class LogEntry
{
	
	
	private EntryType entrytype;
	private String entrymessage;
	private String exceptionmessage = null;
	
	private Date date;
	
	/**
	 * The standard constructor, setting the type of entry and string
	 * entry message.
	 */
	public LogEntry(EntryType inputentrytype, String inputentrymessage)
	{
		entrytype = inputentrytype;
		entrymessage = inputentrymessage;
		date = new Date();
	}
	
	
	/**
	 * Construct a log entry with additional error information provided by
	 * an exception.
	 */
	public LogEntry(EntryType inputentrytype, String inputentrymessage, Exception exception)
	{
		entrytype = inputentrytype;
		entrymessage = inputentrymessage;
		exceptionmessage = exception.toString();
		date = new Date();
	}
	
	/**
	 * Return the entry type.
	 */
	public EntryType getEntryType()
	{
		return entrytype;	
	}
	
	/**
	 * Return the entry message.
	 */
	public String getEntryMessage()
	{
		return entrymessage;	
	}	
	
	/**
	 * Return the exception message, or null if there is no exception message
	 * associated with this LogEntry.
	 */
	public String getExceptionMessage()
	{
		return exceptionmessage;	
	}		
	
	/**
	 * Get the Date object that timestamps this LogEntry.
	 */
	public Date getDate()
	{
		return date;	
	}
	
}
